--[[
	Description: This plugin is part of the "Titan Panel [Currencies] Multi" addon. It shows your amount of Garrison Resources.
	Site: http://www.curse.com/addons/wow/titan-panel-currencies-multi
	Author: Canettieri
	Special Thanks to Eliote, pas06.
--]]

local _, L = ...;
local ACE = LibStub("AceLocale-3.0"):GetLocale("Titan", true)
local version = L["addonversion"]
local ID = "TITAN_GRCTT"
local elap, currencyCount = 0, 0.0
local currencyMaximum
local f = CreateFrame("Button", "TitanPanelTITAN_GRCTTButton", CreateFrame("Frame", nil, UIParent), "TitanPanelComboTemplate")
f:SetFrameStrata("FULLSCREEN")
f:SetScript("OnEvent", function(this, event, ...) this[event](this, ...) end)
f:RegisterEvent("ADDON_LOADED")

function f:ADDON_LOADED(a1)
	if a1 ~= "TitanCurrenciesMulti" then
	return 
	end
	self:UnregisterEvent("ADDON_LOADED")
	self.ADDON_LOADED = nil

	local name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown
	local i = 0
	local CurrencyIndex = 0
	local myicon = "Interface\\Icons\\inv_garrison_resource.blp"
	local mycheck = "Interface\\Icons\\inv_garrison_resource"

	self.registry = {
		id = ID,
		menuText = "Titan|cFF007edd "..L["ResourcesTitle"].."|r",
		buttonTextFunction = "TitanPanelTITAN_GRCTTButton_GetButtonText",
		tooltipTitle = L["ResourcesTitle"],
		tooltipTextFunction = "TitanPanelTITAN_GRCTTButton_GetTooltipText",
		frequency = 2,
		icon = myicon,
		iconWidth = 16,
		category = "Information",
		version = version,
		savedVariables = {
			ShowIcon = 1,
			DisplayOnRightSide = false,
			ShowLabelText = false,
		},
	}
	
	self:SetScript("OnUpdate", function(this, a1)
		elap = elap + a1
		if elap < 1 then return end

		for i = 1, GetCurrencyListSize(), 1 do
			
			name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(i)
			if string.lower(tostring(icon)) == string.lower(mycheck) then
				CurrencyIndex = i
			end
			
		end
		
		name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(CurrencyIndex)

		currencyCount = count
		currencyMaximum = maximum
		
		TitanPanelButton_UpdateButton(ID)
		elap = 0
	end)
		
end

----------------------------------------------
function TitanPanelTITAN_GRCTTButton_GetButtonText()
----------------------------------------------
	local currencyCountText
	if not currencyCount then
		currencyCountText = TitanUtils_GetHighlightText("0")
	elseif currencyCount > 2999 and currencyCount < 5000 then
		currencyCountText = "|cFF69FF69"..currencyCount
	elseif currencyCount > 4999 and currencyCount < 7000 then
		currencyCountText = "|cFFf6ed12"..currencyCount
	elseif currencyCount > 6999 and currencyCount < 9000 then
		currencyCountText = "|cFFf69112"..currencyCount
	elseif currencyCount > 8999 and currencyCount < 10000 then
		currencyCountText = "|cFFFF2e2e"..currencyCount
	elseif currencyCount == currencyMaximum then
		currencyCountText = "|cFFFF2e2e"..L["full"]
	else
		currencyCountText = TitanUtils_GetHighlightText(string.format("%.0f", currencyCount) .."")
	end
	return L["ResourcesLabel"], currencyCountText
end

-----------------------------------------------
function TitanPanelTITAN_GRCTTButton_GetTooltipText()
-----------------------------------------------
	local valorAtual = TitanUtils_GetHighlightText(Util_StringComDefault(currencyCount, "0"))
	local valorMaximo = TitanUtils_GetHighlightText(Util_StringComDefault(currencyMaximum, "0"))
	local ValueText = ""
	if not currencyMaximum then
		ValueText = "|cFFFF2e2e"..L["NoMaxRes"]
	else
		ValueText = L["tooltipCountMaxLabel"]..valorAtual.." / "..valorMaximo
end
	
	return L["ResourcesDescription"].."\r\r"..ValueText
end

----------------------------------------------------
function TitanPanelRightClickMenu_PrepareTITAN_GRCTTMenu()
----------------------------------------------------
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[ID].menuText)
	TitanPanelRightClickMenu_AddToggleIcon(ID)
	TitanPanelRightClickMenu_AddToggleLabelText(ID)
	
info = {};
	info.text = ACE["TITAN_CLOCK_MENU_DISPLAY_ON_RIGHT_SIDE"];
	info.func = TitanPanelTITAN_GRCTTButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	TitanPanelRightClickMenu_AddSpacer();
	TitanPanelRightClickMenu_AddCommand(ACE["TITAN_PANEL_MENU_HIDE"], ID, TITAN_PANEL_MENU_FUNC_HIDE);
end

-----------------------------------------------
function TitanPanelTITAN_GRCTTButton_ToggleRightSideDisplay() -- Right side display
-----------------------------------------------
	TitanToggleVar(ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end

----------------------------------------------------
function Util_StringComDefault(v,d)
----------------------------------------------------
	if not v then
		return d
	end
	
	return v
end